/**
 * Copyright (C) 2019-2021  The Software Heritage developers
 * See the AUTHORS file at the top-level directory of this distribution
 * License: GNU Affero General Public License version 3, or any later version
 * See top-level LICENSE file for more information
 */

// const $ = Cypress.$;

const url = '/requests/takedown/';

function fillIndividualForm() {
  cy.get('#id_reasons').type('My reasons...');
  cy.get('#id_correspondence').type('My correspondence...');
  cy.get('#id_no_longer_accessible').siblings('.form-check-label').click();
  cy.get('#id_contact_email').type('email@example.com');
  cy.get('#id_individual_name').type('Full Name');
  cy.get('#id_individual_activity').type('Manager');
  cy.get('#id_individual_nationality').type('French');
  cy.get('#id_individual_birthdate').type('2000-01-01');
  cy.get('#id_individual_birthplace').type('Paris');
  cy.get('#id_individual_address').type('20 Heritage Court\nSoftware Land\nSL53 5XX\nUK');
}

describe('Takedown requests Tests', () => {

  beforeEach(function() {
    cy.visit(url);
  });

  it('should submit a single origin', () => {
    cy.get('#id_form-0-origin').type('https://git.example.org/project');
    fillIndividualForm();
    cy.get('form.form button[type="submit"]').click();
    cy.get('div.alert-success').should('be.visible');
  });

  it('should submit multiple origin', () => {
    cy.get('#id_form-0-origin').type('https://git.example.org/project');
    cy.get('#add-button').click();
    cy.get('#id_form-1-origin').type('https://example.org/project/multiple/visit/types');
    fillIndividualForm();
    cy.get('form.form button[type="submit"]').click();
    cy.get('div.alert-success').should('be.visible');
  });

  it('should switch between submitter types', () => {
    const individualSelectors = [
      '#id_individual_name',
      '#id_individual_activity',
      '#id_individual_address'
    ];
    const entitySelectors = [
      '#id_entity_name',
      '#id_entity_type',
      '#id_entity_representative',
      '#id_entity_address'
    ];
    // default is individual
    cy.get('input[value="individual"]').should('be.checked');
    individualSelectors.forEach(selector => {
      cy.get(selector).should('be.visible');
    });
    entitySelectors.forEach(selector => {
      cy.get(selector).should('not.be.visible');
    });
    // switch
    cy.get("label[for='id_submitter_type_1']").click();
    individualSelectors.forEach(selector => {
      cy.get(selector).should('not.be.visible');
    });
    entitySelectors.forEach(selector => {
      cy.get(selector).should('be.visible');
    });
    // switch back
    cy.get("label[for='id_submitter_type_0']").click();
    individualSelectors.forEach(selector => {
      cy.get(selector).should('be.visible');
    });
    entitySelectors.forEach(selector => {
      cy.get(selector).should('not.be.visible');
    });
  });

  it('should remove an origin', () => {
    cy.get('#id_form-0-origin').type('https://git.example.org/project');
    // Add two new origins
    cy.get('#add-button').click();
    cy.get('#id_form-1-origin').type('https://many.origins/250');
    cy.get('#add-button').click();
    cy.get('#id_form-2-origin').type('https://example.org/project/multiple/visit/types');
    // Delete the second one
    cy.get('#id_form-1-origin').parent().find('button').click();
    // The form has been reordered
    cy.get('#id_form-0-origin').should('have.value', 'https://git.example.org/project');
    cy.get('#id_form-1-origin').should('have.value', 'https://example.org/project/multiple/visit/types');
    cy.get('#id_form-2-origin').should('not.exist');
  });

  it('should display form errors', () => {
    cy.get('#id_form-0-origin').type('https://git.example.org/project');
    fillIndividualForm();
    cy.get('#id_individual_name').clear();
    cy.get('form.form button[type="submit"]').click();
    cy.get('div.alert-danger').should('be.visible');
  });

  it('should display origin form errors', () => {
    cy.get('#id_form-0-origin').type('https://git.example.org/unknown-origin.git');
    fillIndividualForm();
    cy.get('form.form button[type="submit"]').click();
    cy.get('input.is-invalid').should('be.visible');
  });

});
